# FSDC

The FuckingSimpleDirectoryComparator can find identical files in 2 folders and all of its subfolders.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install FSDC.

```bash
pip install fsdc
```